==> haskell-pager-0.1.1.0-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-9xIKBxgnYw4TklkVj3sb0
key:                  pager-0.1.1.0-9xIKBxgnYw4TklkVj3sb0
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  1aa5994ce4957e09637859c9e8d9784d
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-9xIKBxgnYw4TklkVj3sb0
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-4vOVNW9pwJYLaGSEKs1crY
    conduit-extra-1.3.6-4JqQ81QuGcPCR7VtiWJKw4 directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-HbN0RV9wT5VCrWiuK0rjhN
    safe-0.3.21-AhsGjgyzf9PtCbhiN6ATk terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pager-0.1.1.0-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pager
version:              0.1.1.0
visibility:           public
id:                   pager-0.1.1.0-DDgS7V7pla8BkUhzdFJ8IF
key:                  pager-0.1.1.0-DDgS7V7pla8BkUhzdFJ8IF
license:              BSD-2-Clause
copyright:            Copyright (c) 2015, Peter Harpending.
maintainer:           peter@harpending.org
author:               Peter Harpending
homepage:             https://github.com/pharpend/pager
synopsis:             Open up a pager, like '\''less'\'' or '\''more'\''
description:
    This opens up the user'\''s $PAGER. On Linux, this is usually called @less@. On
    the various BSDs, this is usually @more@.

    CHANGES

    [0.1.1.0] Add @printOrPage@ function and @sendToPagerStrict@ function.

category:             Data, System, Text
abi:                  b1b70ee99c2f6829efb7e9bac953855f
exposed:              True
exposed-modules:      System.Pager
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pager-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pager
hs-libraries:         HSpager-0.1.1.0-DDgS7V7pla8BkUhzdFJ8IF
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-HAJpY08cc65Cd4m5QP3X4q
    conduit-extra-1.3.6-CPHOsyPWtJ828Ihw7K9kVr directory-1.3.7.1
    process-1.6.18.0 resourcet-1.2.6-HbN0RV9wT5VCrWiuK0rjhN
    safe-0.3.21-AhsGjgyzf9PtCbhiN6ATk terminfo-0.4.1.5 text-2.0.2
    transformers-0.5.6.2 unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-pager/html/pager.haddock
haddock-html:         /usr/share/doc/haskell-pager/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
